Dotfiles made easy with Python and Git

# Prerequisite
- Git
- Python3 (not and not going to be tested on python2)
- For more go check [requirements.txt](requirements.txt)

# Installation

# Documentation
